package com.bweb.controller.item;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;
import com.hfkj.common.security.UserCenter;
import com.hfkj.common.utils.ResponseMsgUtil;
import com.hfkj.config.MathConfig;
import com.hfkj.entity.EnItem;
import com.hfkj.entity.EnItemSegments;
import com.hfkj.entity.EnOilDepots;
import com.hfkj.model.ResponseData;
import com.hfkj.model.SecUserSessionObject;
import com.hfkj.service.item.EnItemSegmentsService;
import com.hfkj.service.item.EnOilDepotsService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

@Controller
@RequestMapping(value="/enItemSegments")
@Api(value="项目段管理")
public class EnItemSegmentsController {

    Logger log = LoggerFactory.getLogger(EnItemController.class);
    @Resource
    private UserCenter userCenter;
    @Resource
    private EnItemSegmentsService enItemSegmentsService;


    @RequestMapping(value="/create",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "创建项目段")
    public ResponseData create(@RequestBody EnItemSegments body) {
        try {
            if (body == null
                    || body.getItemId() == null
                    || body.getOilDepotId() == null
                    || body.getLatitude() == null
                    || body.getLongitude() ==  null
                    || StringUtils.isBlank(body.getContactInfo())
                    || StringUtils.isBlank(body.getAddress())
                    || StringUtils.isBlank(body.getSegmentName())
                    || StringUtils.isBlank(body.getPerson())
            ) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);

            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }

            body.setUpdateTime(new Date());
            body.setCreateTime(new Date());
            body.setCreateUser(sessionModel.getAccount().getId());
            body.setStatus(2);
            body.setCreateUserName(sessionModel.getAccount().getUserName());
            enItemSegmentsService.create(body);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/update",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "修改油库")
    public ResponseData update(@RequestBody EnItemSegments body) {
        try {
            if (body == null
                    || body.getId() == null
                    || body.getItemId() == null
                    || body.getOilDepotId() == null
                    || body.getLatitude() == null
                    || body.getLongitude() ==  null
                    || StringUtils.isBlank(body.getContactInfo())
                    || StringUtils.isBlank(body.getAddress())
                    || StringUtils.isBlank(body.getSegmentName())
                    || StringUtils.isBlank(body.getPerson())
            ) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);

            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }
            Map<String , Object > map = new HashMap<>();

            map.put("id",body.getId());
            map.put("createUser" , sessionModel.getAccount().getId());

            EnItemSegments enItemSegments = enItemSegmentsService.queryDetailByMap(map);

            if (enItemSegments == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "项目段不存在");
            }

            enItemSegments.setItemId(body.getItemId());
            enItemSegments.setOilDepotId(body.getOilDepotId());
            enItemSegments.setLatitude(body.getLatitude());
            enItemSegments.setLongitude(body.getLongitude());
            enItemSegments.setContactInfo(body.getContactInfo());
            enItemSegments.setAddress(body.getAddress());
            enItemSegments.setSegmentName(body.getSegmentName());
            enItemSegments.setPerson(body.getPerson());
            enItemSegments.setUpdateTime(new Date());
            enItemSegments.setUpdateTime(new Date());
            enItemSegments.setUpdateUser(sessionModel.getAccount().getId());
            enItemSegments.setUpdateUserName(sessionModel.getAccount().getUserName());
            enItemSegmentsService.update(enItemSegments);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/updateStatus",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "修改状态")
    public ResponseData updateStatus(@RequestBody EnItem body) {
        try {
            if (body == null
                    || body.getId() == null
                    || body.getStatus() == null
            ) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);
            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }

            Map<String , Object > map = new HashMap<>();

            map.put("id",body.getId());
            map.put("createUser" , sessionModel.getAccount().getId());

            EnItemSegments enItemSegments = enItemSegmentsService.queryDetailByMap(map);

            if (enItemSegments == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "项目段不存在");
            }

            enItemSegments.setStatus(body.getStatus());
            enItemSegments.setUpdateTime(new Date());
            enItemSegments.setUpdateUser(sessionModel.getAccount().getId());
            enItemSegments.setUpdateUserName(sessionModel.getAccount().getUserName());
            enItemSegmentsService.update(enItemSegments);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }


    @RequestMapping(value="/deleteItem",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "删除")
    public ResponseData deleteGoods(@RequestParam(value = "id" , required = false) Long id) {
        try {

            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);
            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }

            Map<String , Object > map = new HashMap<>();

            map.put("id",id);
            map.put("createUser" , sessionModel.getAccount().getId());

            EnItemSegments enItemSegments = enItemSegmentsService.queryDetailByMap(map);
            if (enItemSegments == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "油库不存在");
            }

            enItemSegmentsService.delete(id , false);

            return ResponseMsgUtil.success("删除成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }



    @RequestMapping(value="/queryDetail",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询详情")
    public ResponseData queryDetail(@RequestParam(value = "id" , required = false) Long id) {
        try {

            return ResponseMsgUtil.success(enItemSegmentsService.queryDetail(id));

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/queryList",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询项目列表")
    public ResponseData queryList(@RequestParam(value = "itemId" , required = false) Long itemId,
                                  @RequestParam(value = "oilDepotId" , required = false) Long oilDepotId,
                                  @RequestParam(value = "segmentName" , required = false) String segmentName,
                                  @RequestParam(value = "address" , required = false) String address,
                                  @RequestParam(value = "status" , required = false) Integer status,
                                  @RequestParam(value = "person" , required = false) String person,
                                  @RequestParam(value = "contactInfo" , required = false) String contactInfo,
                                  @RequestParam(value = "pageNum" , required = true) Integer pageNum,
                                  @RequestParam(value = "pageSize" , required = true) Integer pageSize) {
        try {
            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);
            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }

            Map<String,Object> param = new HashMap<>();
            param.put("contactInfo", contactInfo);
            param.put("itemId", itemId);
            param.put("oilDepotId", oilDepotId);
            param.put("segmentName", segmentName);
            param.put("person", person);
            param.put("status", status);
            param.put("createUser", sessionModel.getAccount().getId());

            PageHelper.startPage(pageNum, pageSize);
            return ResponseMsgUtil.success(new PageInfo<>(enItemSegmentsService.getList(param)));

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }
}
